@@ -44,11 +44,13 @@ pygments_style = 'sphinx'
 # Sphinx are currently 'default' and 'sphinxdoc'.
 # html_theme_path = ["."]
 # html_theme = '_theme'
-html_static_path = ['static']
+# html_static_path = ['static']
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
 
+modindex_common_prefix = ['glance_store.']
+
 git_cmd = ["git", "log", "--pretty=format:'%ad, commit %h'", "--date=local",
            "-n1"]
 html_last_updated_fmt = subprocess.Popen(git_cmd,
