@@ -84,22 +84,7 @@ class OptsTestCase(base.StoreBaseTest):
             'rbd_store_user',
             'rados_connect_timeout',
             'rootwrap_config',
-            's3_store_access_key',
-            's3_store_bucket',
-            's3_store_bucket_url_format',
-            's3_store_create_bucket_on_put',
-            's3_store_host',
-            's3_store_object_buffer_dir',
-            's3_store_secret_key',
-            's3_store_large_object_size',
-            's3_store_large_object_chunk_size',
-            's3_store_thread_pools',
-            's3_store_enable_proxy',
             'swift_store_expire_soon_interval',
-            's3_store_proxy_host',
-            's3_store_proxy_port',
-            's3_store_proxy_user',
-            's3_store_proxy_password',
             'sheepdog_store_address',
             'sheepdog_store_chunk_size',
             'sheepdog_store_port',
